@@ -8,32 +8,31 @@ use std::sync::Arc;
 use std::time::Instant;
 
 fn assert_in_range<T: PartialOrd + Debug>(range: Range<T>, value: &T) {
-    if range.is_empty() {
-        panic!("invalid range {:?}", range)
-    }
+    assert!(!range.is_empty(), "invalid range {:?}", range);
     // println!(
     //     "measured concurrency value {:?}, expected range {:?}",
     //     value, range,
     // );
-    if !range.contains(value) {
-        panic!(
-            "measured concurrency value {:?} out of range {:?}",
-            value, range,
-        );
-    }
+    assert!(
+        range.contains(value),
+        "measured concurrency value {:?} out of range {:?}",
+        value,
+        range,
+    );
 }
 
 /// # Panics
 /// Panics if the elapsed time since `before` is outside of `range_ms`.
 pub fn assert_elapsed(before: Instant, range_ms: Range<u64>) {
-    if range_ms.is_empty() {
-        panic!("invalid range {:?}", range_ms)
-    }
+    assert!(!range_ms.is_empty(), "invalid range {:?}", range_ms);
     let elapsed = before.elapsed();
     let duration_range = Duration::from_millis(range_ms.start)..Duration::from_millis(range_ms.end);
-    if !duration_range.contains(&elapsed) {
-        panic!("{:?} elapsed, out of range {:?}", elapsed, duration_range);
-    }
+    assert!(
+        duration_range.contains(&elapsed),
+        "{:?} elapsed, out of range {:?}",
+        elapsed,
+        duration_range
+    );
 }
 
 fn measure_async_concurrency(executor: &Arc<Executor>, num_jobs: usize) -> f32 {
@@ -97,14 +96,15 @@ async fn expect_blocking_concurrency(executor: &Arc<Executor>, num_tasks: usize)
 }
 
 fn expect_elapsed(before: Instant, range: Range<Duration>) {
-    if range.is_empty() {
-        panic!("invalid range {:?}", range)
-    }
+    assert!(!range.is_empty(), "invalid range {:?}", range);
     let elapsed = before.elapsed();
     println!("{:?} elapsed, expected range {:?}", elapsed, range);
-    if !range.contains(&elapsed) {
-        panic!("{:?} elapsed, out of range {:?}", elapsed, range);
-    }
+    assert!(
+        range.contains(&elapsed),
+        "{:?} elapsed, out of range {:?}",
+        elapsed,
+        range
+    );
 }
 
 fn get_async_thread_name(executor: &Arc<Executor>) -> String {
@@ -172,7 +172,7 @@ fn test_default_trait() {
 
 #[test]
 fn test_new() {
-    let executor = Executor::new(2, 2);
+    let executor = Executor::new(2, 2).unwrap();
     expect_async_concurrency(&executor, 2);
     assert_eq!(
         "async",
@@ -195,7 +195,7 @@ fn test_new() {
 
 #[test]
 fn test_with_name() {
-    let executor = Executor::with_name("exec", 2, "io", 2);
+    let executor = Executor::with_name("exec", 2, "io", 2).unwrap();
     expect_async_concurrency(&executor, 2);
     assert_eq!(
         "exec",
@@ -256,7 +256,7 @@ fn test_waking() {
 #[test]
 fn test_async_panic() {
     // Start a single thread.
-    let executor = safina_executor::Executor::new(1, 1);
+    let executor = safina_executor::Executor::new(1, 1).unwrap();
     // Run a future that panics.
     executor.spawn(async move {
         panic!("ignore this panic");
@@ -273,7 +273,7 @@ fn test_async_panic() {
 #[test]
 fn test_executor_block_on() {
     safina_timer::start_timer_thread();
-    let executor = safina_executor::Executor::new(1, 1);
+    let executor = safina_executor::Executor::new(1, 1).unwrap();
     assert_eq!(3_u8, executor.block_on(async { 3_u8 }));
     let value = 5_u8;
     assert_eq!(5_u8, executor.block_on(async move { value }));
@@ -287,6 +287,7 @@ fn test_executor_block_on() {
     );
     std::panic::catch_unwind(|| {
         executor.block_on(async {
+            #[allow(clippy::manual_assert)]
             if true {
                 panic!("ignore this panic");
             }
@@ -319,6 +320,7 @@ fn test_block_on() {
     );
     std::panic::catch_unwind(|| {
         safina_executor::block_on(async {
+            #[allow(clippy::manual_assert)]
             if true {
                 panic!("ignore this panic");
             }
@@ -347,7 +349,7 @@ fn test_block_on_unpin() {
 #[test]
 fn test_executor_schedule_blocking() {
     safina_timer::start_timer_thread();
-    let executor = safina_executor::Executor::new(2, 2);
+    let executor = safina_executor::Executor::new(2, 2).unwrap();
     let executor_clone = executor.clone();
     executor.block_on(async move {
         assert_eq!(3_u8, executor_clone.schedule_blocking(|| 3_u8).await);
@@ -369,6 +371,7 @@ fn test_executor_schedule_blocking() {
         );
         safina_timer::with_timeout(
             executor_clone.schedule_blocking(|| {
+                #[allow(clippy::manual_assert)]
                 if true {
                     panic!("ignore this panic");
                 }
@@ -395,7 +398,7 @@ fn test_executor_schedule_blocking() {
 #[test]
 fn test_schedule_blocking() {
     safina_timer::start_timer_thread();
-    let executor = safina_executor::Executor::new(1, 1);
+    let executor = safina_executor::Executor::new(1, 1).unwrap();
     executor.block_on(async {
         assert_eq!(3_u8, safina_executor::schedule_blocking(|| 3_u8).await);
         let value = 5_u8;
@@ -418,6 +421,7 @@ fn test_schedule_blocking() {
         );
         safina_timer::with_timeout(
             safina_executor::schedule_blocking(|| {
+                #[allow(clippy::manual_assert)]
                 if true {
                     panic!("ignore this panic");
                 }
